import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import { readFileSync } from 'node:fs';
import { normalizeSVGProps, parseSVG } from '../rendering/svg.js';
import { resolveImagePath } from '../slidesets/loaders.js';
export function Svg({ theme, contents, ...props }) {
    const [svgProps, svgContents] = parseSVG(readFileSync(resolveImagePath(theme, '', contents), 'utf8'));
    return /*#__PURE__*/ _jsx("svg", {
        ...normalizeSVGProps(svgProps),
        ...props,
        dangerouslySetInnerHTML: {
            __html: svgContents
        }
    });
}
export function SvgIcon(props) {
    const { viewBoxWidth: rawViewBoxWidth, viewBoxHeight: rawViewBoxHeight, theme, name } = props;
    const rawContents = readFileSync(resolveImagePath(theme, '', `@theme/icons/${name}.svg`), 'utf8');
    const viewBoxWidth = rawViewBoxWidth ?? 24;
    const viewBoxHeight = rawViewBoxHeight ?? 24;
    const [svgProps, svgContents] = parseSVG(rawContents);
    return /*#__PURE__*/ _jsx("svg", {
        ...normalizeSVGProps(svgProps),
        viewBox: `0 0 ${viewBoxWidth} ${viewBoxHeight}`,
        ...props,
        dangerouslySetInnerHTML: {
            __html: svgContents
        }
    });
}
export function SvgCloseIcon(props) {
    return /*#__PURE__*/ _jsxs("svg", {
        xmlns: "http://www.w3.org/2000/svg",
        viewBox: "0 0 24 24",
        strokeWidth: "2",
        stroke: "currentColor",
        fill: "none",
        strokeLinecap: "round",
        strokeLinejoin: "round",
        ...props,
        children: [
            /*#__PURE__*/ _jsx("path", {
                stroke: "none",
                d: "M0 0h24v24H0z",
                fill: "none"
            }),
            /*#__PURE__*/ _jsx("line", {
                x1: "18",
                y1: "6",
                x2: "6",
                y2: "18"
            }),
            /*#__PURE__*/ _jsx("line", {
                x1: "6",
                y1: "6",
                x2: "18",
                y2: "18"
            })
        ]
    });
}
