import { jsx as _jsx, jsxs as _jsxs, Fragment as _Fragment } from "react/jsx-runtime";
import { danteDir } from 'dante';
import { readFile } from 'node:fs/promises';
import { resolve } from 'node:path';
import { fileURLToPath } from 'node:url';
import { finalizeJs } from '../slidesets/generators.js';
const style = `
*,
*:hover,
*:focus,
*:active,
*::before,
*::after {
  box-sizing: border-box;
  outline: none;
}

@font-face {
  font-family: 'Poppins';
  font-style: normal;
  font-weight: 700;
  font-display: swap;
  src: url(https://fonts.gstatic.com/s/poppins/v20/pxiByp8kv8JHgFVrLCz7Z1xlFd2JQEk.woff2) format(woff2);
  unicode-range: U+0000-00FF, U+0131, U+0152-0153, U+02BB-02BC, U+02C6, U+02DA, U+02DC, U+2000-206F, U+2074,
    U+20AC, U+2122, U+2191, U+2193, U+2212, U+2215, U+FEFF, U+FFFD;
}

body {
  margin: 0;
  width: 100%;
  min-height: 100%;
}

main {
  display: flex;
  flex-direction: column;
  width: 80%;
  max-width: 80vw;
  row-gap: 5ch;
  margin: 40pt;
}

nav {
  display: flex;
  flex-direction: column;
  row-gap: 6ch;
}

h1, h2, h4 {
  font-family: Poppins, -apple-system, BlinkMacSystemFont, 'Segoe UI', Roboto, Helvetica, Arial, sans-serif,
    'Apple Color Emoji', 'Segoe UI Emoji', 'Segoe UI Symbol';
  margin: 0;
  line-height: 1.4em;
}

h1 {
  font-size: 35pt;
}

h2 {
  font-size: 25pt;
}

h4 {
  color: #fb7a9c;
  font-size: 18pt;
}

a,
a:hover,
a:active,
a:visited,
a:focus {
  color: #2165e3;
  text-decoration: none;
}

a:hover, a:hover h4 {
  color: #ecb22e;
}
`;
export function body({ talks }) {
    const allTalks = Object.entries(talks);
    const currentTalks = allTalks.filter(([, talk])=>!talk.document.archived);
    const archivedTalks = allTalks.filter(([, talk])=>talk.document.archived);
    return /*#__PURE__*/ _jsxs("main", {
        children: [
            currentTalks.length > 0 && /*#__PURE__*/ _jsxs(_Fragment, {
                children: [
                    /*#__PURE__*/ _jsx("h1", {
                        children: "Current Slidesets"
                    }),
                    /*#__PURE__*/ _jsx("nav", {
                        children: currentTalks.map(([id, talk])=>/*#__PURE__*/ _jsxs("a", {
                                href: `/${id}`,
                                children: [
                                    /*#__PURE__*/ _jsx("h2", {
                                        children: talk.document.title
                                    }),
                                    /*#__PURE__*/ _jsx("h4", {
                                        children: talk.document.author.name
                                    })
                                ]
                            }, `talk:${id}`))
                    })
                ]
            }),
            archivedTalks.length > 0 && /*#__PURE__*/ _jsxs(_Fragment, {
                children: [
                    /*#__PURE__*/ _jsx("h1", {
                        children: "Archived Slidesets"
                    }),
                    /*#__PURE__*/ _jsx("nav", {
                        children: archivedTalks.map(([id, talk])=>/*#__PURE__*/ _jsxs("a", {
                                href: `/${id}`,
                                children: [
                                    /*#__PURE__*/ _jsx("h2", {
                                        children: talk.document.title
                                    }),
                                    /*#__PURE__*/ _jsx("h4", {
                                        children: talk.document.author.name
                                    })
                                ]
                            }, `talk:${id}`))
                    })
                ]
            })
        ]
    });
}
export async function page(context) {
    const siteVersion = `globalThis.__freyaSiteVersion = "${context.extensions.version}"`;
    const hotReload = !context.isProduction ? await readFile(resolve(danteDir, 'dist/assets/hot-reload-trigger.js'), 'utf8') : '';
    const serviceWorker = context.isProduction ? await readFile(fileURLToPath(new URL('../assets/js/service-worker.js', import.meta.url)), 'utf8') : '';
    const js = await finalizeJs([
        siteVersion,
        hotReload,
        serviceWorker
    ].join('\n;\n'));
    return /*#__PURE__*/ _jsxs("html", {
        lang: "en",
        children: [
            /*#__PURE__*/ _jsxs("head", {
                children: [
                    /*#__PURE__*/ _jsx("meta", {
                        charSet: "utf-8"
                    }),
                    /*#__PURE__*/ _jsx("meta", {
                        name: "viewport",
                        content: "width=device-width, initial-scale=1"
                    }),
                    /*#__PURE__*/ _jsx("title", {
                        children: "Slidesets"
                    }),
                    /*#__PURE__*/ _jsx("link", {
                        rel: "preload",
                        as: "font",
                        crossOrigin: "anonymous",
                        href: "https://fonts.gstatic.com/s/poppins/v20/pxiByp8kv8JHgFVrLCz7Z1xlFd2JQEk.woff2"
                    }),
                    /*#__PURE__*/ _jsx("script", {
                        defer: true,
                        type: "text/javascript",
                        dangerouslySetInnerHTML: {
                            __html: js
                        }
                    }),
                    /*#__PURE__*/ _jsx("style", {
                        dangerouslySetInnerHTML: {
                            __html: style
                        }
                    })
                ]
            }),
            /*#__PURE__*/ _jsx("body", {
                children: "@BODY@"
            })
        ]
    });
}
